# akrocansim
Akrocansim is a CAN bus controller simulator offering a graphical interface for manipulating transmitted signals.

Currently, there is partial support for J1939.

Akrocansim is built using [DearPyGUI](https://github.com/hoffstadt/DearPyGui) and [python-can](https://github.com/hardbyte/python-can).

Install: `pip install akrocansim`

Run: `python -m akrocansim`

Feel free to raise issues at https://github.com/cfsok/akrocansim/issues

![Akrocansim demo screenshot 1](https://raw.githubusercontent.com/cfsok/akrocansim/main/docs/demo_1_Akrocansim.png)
![Akrocansim demo screenshot 2](https://raw.githubusercontent.com/cfsok/akrocansim/main/docs/demo_2_Akrocansim.png)
![PCAN-View demo screenshot 1](https://raw.githubusercontent.com/cfsok/akrocansim/main/docs/demo_1_PCAN-View.png)
